@@ -1,14 +1,12 @@
 package Text::WordDiff;
 
-# $Id: WordDiff.pm 3752 2008-05-05 03:23:55Z david $
-
 use strict;
 use vars qw(@ISA $VERSION);
 use Algorithm::Diff ();
 use IO::File;
 use Carp;
 
-$VERSION = '0.03';
+$VERSION = '0.06';
 
 # _Mastering Regular Expressions_, p. 132.
 my $BEGIN_WORD = $] >= 5.006
@@ -16,8 +14,9 @@ my $BEGIN_WORD = $] >= 5.006
     : qr/(?<!\w)(?=\w)/msx;
 
 my %styles = (
-    ANSIColor => undef,
-    HTML      => undef,
+    ANSIColor    => undef,
+    HTML         => undef,
+    HTMLTwoLines => undef,
 );
 
 sub import {
@@ -579,7 +578,7 @@ This module is stored in an open repository at the following address:
 
 L<https://svn.kineticode.com/Text-WordDiff/trunk/>
 
-Patches against SVN::Notify are welcome. Please send bug reports to
+Patches against Text::WordDiff are welcome. Please send bug reports to
 <bug-text-worddiff@rt.cpan.org>.
 
 =head1 Author
@@ -597,7 +596,7 @@ David Wheeler <david@kineticode.com>
 
 =head1 Copyright and License
 
-Copyright (c) 2005-2008 David Wheeler. Some Rights Reserved.
+Copyright (c) 2005-2011 David E. Wheeler. Some Rights Reserved.
 
 This module is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
