@@ -7,7 +7,7 @@ use vars qw($VERSION @ISA);
 # Term::ANSIColor doesn't support STRIKETHROUGH, so we'll do it ourselves.
 use constant STRIKETHROUGH => "\e[9m";
 
-$VERSION = '0.03';
+$VERSION = '0.06';
 @ISA = qw(Text::WordDiff::Base);
 
 sub same_items {
@@ -61,7 +61,7 @@ Text::WordDiff::ANSIColor - ANSI colored formatting for Text::WordDiff
 This class subclasses Text::WordDiff::Base to provide a formatting class for
 Text::WordDiff that uses ANSI-standard terminal escape sequences to highlight
 deleted and inserted text. This formatting class is the default class used by
-L<Term::WordDiff|Term::WordDiff>; see its documentation for details on its
+L<Text::WordDiff|Text::WordDiff>; see its documentation for details on its
 interface. This class should never be used directly.
 
 Text::WordDiff::ANSIColor formats word diffs for viewing in an ANSI-standard
@@ -99,7 +99,7 @@ This module is stored in an open repository at the following address:
 
 L<https://svn.kineticode.com/Text-WordDiff/trunk/>
 
-Patches against SVN::Notify are welcome. Please send bug reports to
+Patches against Text::WordDiff are welcome. Please send bug reports to
 <bug-text-worddiff@rt.cpan.org>.
 
 =head1 Author
@@ -117,7 +117,7 @@ David Wheeler <david@kineticode.com>
 
 =head1 Copyright and License
 
-Copyright (c) 2005-2008 David Wheeler. Some Rights Reserved.
+Copyright (c) 2005-2011 David E. Wheeler. Some Rights Reserved.
 
 This module is free software; you can redistribute it and/or modify it under the
 same terms as Perl itself.
